import React, { useState, useEffect } from 'react';
import { Feather as Icon } from '@expo/vector-icons';
import { View, ImageBackground, Image, Text, StyleSheet, Picker } from 'react-native';
import { RectButton } from 'react-native-gesture-handler';
import { useNavigation } from '@react-navigation/native';

import axios from '../../services/api';

interface State {
  sigla: string;
}

interface City {
  nome: string;
}

const Home = () => {
  const [state, setState] = useState<String[]>([]);
  const [city, setCity] = useState<String[]>([]);
  const [selectedState, setSelectedState] = useState('0');
  const [selectedCity, setSelectedCity] = useState('0');

  const { navigate } = useNavigation();

  useEffect(() => {
    axios
      .get<State[]>('https://servicodados.ibge.gov.br/api/v1/localidades/estados')
      .then(response => {
        const stateInitials = response.data.map(state => state.sigla);

        setState(stateInitials);
      });
  }, []);

  useEffect(() => {
    if (selectedState === '0') {
      return;
    }

    axios
      .get<City[]>(`https://servicodados.ibge.gov.br/api/v1/localidades/estados/${selectedState}/municipios`)
      .then(response => {
        const citiesNames = response.data.map(city => city.nome);

        setCity(citiesNames);
      })
  }, [selectedState]);

  function handleNavigateToPoints() {
    navigate('Points', { selectedState, selectedCity });
  }

  return (
    <ImageBackground
      source={require('../../assets/home-background.png')}
      style={styles.container}
      imageStyle={{ width: 275, height: 368 }}
    >
      <View style={styles.main}>
        <Image source={require('../../assets/logo.png')} />
        <View>
          <Text style={styles.title}>Seu marketplace de coleta de resíduos</Text>
          <Text style={styles.description}>
            Ajudamos pessoas a encontrarem pontos de coleta de forma eficiente.
            </Text>
        </View>
      </View>

      <View>
        <Picker
          selectedValue={selectedState}
          onValueChange={(itemValue, itemIndex) => setSelectedState(itemValue)}>
          <Picker.Item label="Selecione um estado" value="Selecione um estado" />
          {state.map(state => (
            <Picker.Item key={String(state)} label={String(state)} value={String(state)} />
          ))}
        </Picker>

        <Picker
          selectedValue={selectedCity}
          onValueChange={(itemValue, itemIndex) => setSelectedCity(itemValue)}>
          <Picker.Item label="Selecione uma cidade" value="Selecione uma cidade" />
          {city.map(city => (
            <Picker.Item key={String(city)} label={String(city)} value={String(city)} />
          ))}
        </Picker>
      </View>

      <RectButton style={styles.button} onPress={handleNavigateToPoints}>
        <View style={styles.buttonIcon}>
          <Text>
            <Icon name="arrow-right" color="#fff" size={24} />
          </Text>
        </View>
        <Text style={styles.buttonText}>Entrar</Text>
      </RectButton>
    </ImageBackground>
  );
}

const styles = StyleSheet.create({
  container: {
    flex: 1,
    padding: 32,
  },

  main: {
    flex: 1,
    justifyContent: 'center',
  },

  title: {
    color: '#322153',
    fontSize: 32,
    fontFamily: 'Ubuntu_700Bold',
    maxWidth: 260,
    marginTop: 64,
  },

  description: {
    color: '#6C6C80',
    fontSize: 16,
    marginTop: 16,
    fontFamily: 'Roboto_400Regular',
    maxWidth: 260,
    lineHeight: 24,
  },

  input: {
    height: 60,
    backgroundColor: '#FFF',
    borderRadius: 10,
    marginBottom: 8,
    paddingHorizontal: 24,
    fontSize: 16,
  },

  button: {
    backgroundColor: '#34CB79',
    height: 60,
    flexDirection: 'row',
    borderRadius: 10,
    overflow: 'hidden',
    alignItems: 'center',
    marginTop: 8,
  },

  buttonIcon: {
    height: 60,
    width: 60,
    backgroundColor: 'rgba(0, 0, 0, 0.1)',
    justifyContent: 'center',
    alignItems: 'center'
  },

  buttonText: {
    flex: 1,
    justifyContent: 'center',
    textAlign: 'center',
    color: '#FFF',
    fontFamily: 'Roboto_500Medium',
    fontSize: 16,
  }
});

export default Home;